@@ -7,7 +7,7 @@ from starlette.responses import JSONResponse
 from fastapi import FastAPI
 from starlette import status
 from kafka import KafkaConsumer
-from kafka.errors import KafkaError, NoBrokersAvailable
+from kafka.errors import KafkaError
 from google.cloud import bigquery
 from google.oauth2 import service_account
 from knada_kafka_consumer.bq import bigquery_writer
@@ -48,9 +48,12 @@ class ConsumerApp:
 
     def read_topic(self):
         consumer = self.create_consumer()
+        logging.info("Created consumer")
         bq_client = self.create_bq_client()
+        logging.info("Created bq client")
         bq_table = bigquery_writer.get_bq_table(bq_client=bq_client,
                                                 table_name=self._bq_table)
+        logging.info("Fetched bq table")
 
         try:
             for mesg in consumer:
